using System;
using System.IO;
using System.Reflection;
using System.Collections;
using System.Collections.Generic;
using System.Text;

namespace ReadFileViaReflection
{
    /// <summary>
    /// This class parses testdata.txt into a strongly typed class.
    /// After parsing the data, Items contains all the inventory items.
    /// 
    /// Kerry Wong, http://www.kerrywong.com
    /// </summary>
    class FileParser
    {
        string _fileName = string.Empty;
        InventoryItem _content = null;
        List<InventoryItem> _items = null;

        public List<InventoryItem> Items
        {
            get {return _items;}
            set {_items = value;}
        }

        public FileParser(string fileName)
        {
            _fileName = fileName;
            _items = new List<InventoryItem>();
        }

        public void Parse()
        {
            StreamReader fileStream = new StreamReader(Path.Combine(Environment.CurrentDirectory, _fileName));
            string line = string.Empty;

            line = fileStream.ReadLine();

            do
            {
                if (line == null) break;

                if (line.Trim().IndexOf(";----") == 0)
                {
                    if (_content == null)
                    {
                        _content = new InventoryItem();
                    }
                    else
                    {
                        _items.Add(_content);
                        _content = new InventoryItem();
                    }
                }
                else
                {
                    AddMemberInformation(line);
                }
                line = fileStream.ReadLine();
            } while (line != null);

            fileStream.Close();
        }

        private void AddMemberInformation(string line)
        {
            string[] ay = line.Split('=');

            Type t = _content.GetType();

            FieldInfo field = t.GetField(String.Concat("_", ay[0].Trim()), BindingFlags.Instance | BindingFlags.NonPublic);
            field.SetValue(_content, ay[1].Trim());
        }
    }
}
